BestFirstRule

Struct BestFirstRule 

pub struct BestFirstRule { /* private fields */ }
BestFirstRule represents a rule that executes the first child that evaluates to true. If no child evaluates to true, it tries siblings until one succeeds.

Example

use dredd_rs::rule::*;

let mut rule = BestFirstRule::new();
rule.set_eval_fn(|context| {
    context.get_bool("should_execute")
});
rule.set_execute_fn(|context| {
    context.set_bool("executed", true);
    Ok(())
});

let mut context = RuleContext::new();
context.set_bool("should_execute", true);

let result = rule.fire(&mut context).unwrap();
assert!(result);

Implementations

Source

impl BestFirstRule

pub fn new() -> Self

Create a new BestFirstRule

pub fn set_eval_fn<F>(&mut self, f: F) -> &mut Self
where F: Fn(&RuleContext) -> RuleResult<bool> + 'static,

Set the evaluation function

pub fn set_pre_execute_fn<F>(&mut self, f: F) -> &mut Self
where F: Fn(&mut RuleContext) -> RuleResult<()> + 'static,

Set the pre-execution function

pub fn set_execute_fn<F>(&mut self, f: F) -> &mut Self
where F: Fn(&mut RuleContext) -> RuleResult<()> + 'static,

Set the execution function

pub fn set_post_execute_fn<F>(&mut self, f: F) -> &mut Self
where F: Fn(&mut RuleContext) -> RuleResult<()> + 'static,

Set the post-execution function