pub struct ChainRule { /* private fields */ }Expand description
ChainRule represents a rule that can have at most one child. When executed, it will run its child rule if the evaluation succeeds.
Example
use dredd_rs::rule::*;
let mut rule = ChainRule::new();
rule.set_eval_fn(|context| {
context.get_bool("should_execute")
});
rule.set_execute_fn(|context| {
context.set_bool("executed", true);
Ok(())
});
let mut context = RuleContext::new();
context.set_bool("should_execute", true);
let result = rule.fire(&mut context).unwrap();
assert!(result);Implementations
Sourceimpl ChainRule
impl ChainRule
Sourcepub fn set_eval_fn<F>(&mut self, f: F) -> &mut Self
pub fn set_eval_fn<F>(&mut self, f: F) -> &mut Self
Set the evaluation function
Sourcepub fn set_pre_execute_fn<F>(&mut self, f: F) -> &mut Self
pub fn set_pre_execute_fn<F>(&mut self, f: F) -> &mut Self
Set the pre-execution function
Sourcepub fn set_execute_fn<F>(&mut self, f: F) -> &mut Self
pub fn set_execute_fn<F>(&mut self, f: F) -> &mut Self
Set the execution function
Sourcepub fn set_post_execute_fn<F>(&mut self, f: F) -> &mut Self
pub fn set_post_execute_fn<F>(&mut self, f: F) -> &mut Self
Set the post-execution function
Sourcepub fn set_child(&mut self, child: Box<dyn Rule>) -> RuleResult<&mut Self>
pub fn set_child(&mut self, child: Box<dyn Rule>) -> RuleResult<&mut Self>
Add a child rule (ChainRule can only have one child)